# colourz
Print in colour, with no extra charge!

## Installation

`$ pipenv install colourz`

## Usage

```
from colourz import Colourz

# Print in bold text
>>> print(Colourz.bold("Bold text))

# Print text in red
>>> print(Colourz.normal("Red text", "RED"))

# Print text in bold red
>>> print(Colourz.bold("Bold red text", "RED"))
```
